globalVariables(c('top', 'buttonsFrame', 'optionsFrame', 'catalogVariable',
 'rowsFrame', 'catalogFrame', 'errorbartypeFrame', 'errorbartypeVariable',
 'formulaFrame', 'lettertypeFrame', 'lettertypeVariable', 'modeltypeFrame', 
 'modeltypeVariable', 'ordertypeFrame', 'ordertypeVariable', 'outerOperatorsFrame',
 'positiontypeFrame', 'positiontypeVariable', 'responsetypeFrame',
 'responsetypeVariable', 'rhsVariable', 'scoretypeFrame', 'scoretypeVariable',
 'subsetFrame', 'subsetVariable', 'xBox', 'yesVariable', 'nrowsValue', 
 '.tableFrame1', '.tableFrame2', '.tableFrame3'))

